==> SnareCore-2.4.zip: SnareCore/WebPages.h <==
int		HandleWebPages(char *HTTPBuffer,char *HTTPOutputBuffer,int size,SOCKET http_socket, HANDLE event);

int		Status_Page(char *source, char *dest, int size);
int		DefaultHeader(char *source, char *dest, int size);
int		Network_Config(char *source, char *dest, int size);
int		Remote_Config(char *source, char *dest, int size);
int		Remote_Set(char *source, char *dest, int size);
int		Objective_Config(char *source, char *dest, int size);
int		DefaultFooter(char *source, char *dest, int size);

int		Pipe_Request(char *source, char *dest, int size);
int		InterSectImage(char *source, char *dest, int size);
int		Objective_Display(char *source, char *dest, int size);
int		Restart(char *source, char *dest, int size, HANDLE event);
int		Network_Set(char *source, char *dest, int size);
int		Objective_Result(char *, char *, int);

extern int     ReadObjectives();
extern void    DestroyList(void);
int		debracket(char *source, char *dest, int length);

int		ShowLocalUsers(SOCKET http_socket);
int		ShowLocalGroups(SOCKET http_socket);

int		ShowDomainUsers(SOCKET http_socket);
int		ShowDomainGroups(SOCKET http_socket);

int		ShowLocalGroupMembers(SOCKET http_socket);
int		ShowThisLocalGroupMembers(WCHAR *Group,SOCKET http_socket);

int		ShowDomainGroupMembers(SOCKET http_socket);
int		ShowThisDomainGroupMembers(WCHAR *Group,WCHAR *PDC,SOCKET http_socket);

// Stuff we use from webserver.h
int		base64decode(char *dest, char *src);
char *	GetNextArgument(char *source,char *destvar,int varlength,char *destval,int vallength);

int		DisplayTextHeader(SOCKET http_socket);

BOOL	GetUserSid(LPTSTR szName,LPTSTR TextualSid,LPDWORD lpdwBufferLen);
BOOL	GetTextualSid(PSID pSid,LPTSTR TextualSid,LPDWORD lpdwBufferLen);

==> SnareCore-2.4.4.zip: SnareCore/WebPages.h <==
int		HandleWebPages(char *HTTPBuffer,char *HTTPOutputBuffer,int size,SOCKET http_socket, HANDLE event);

int		Status_Page(char *source, char *dest, int size);
int		DefaultHeader(char *source, char *dest, int size);
int		Network_Config(char *source, char *dest, int size);
int		Remote_Config(char *source, char *dest, int size);
int		Remote_Set(char *source, char *dest, int size);
int		Objective_Config(char *source, char *dest, int size);
int		DefaultFooter(char *source, char *dest, int size);

int		Pipe_Request(char *source, char *dest, int size);
int		InterSectImage(char *source, char *dest, int size);
int		Objective_Display(char *source, char *dest, int size);
int		Restart(char *source, char *dest, int size, HANDLE event);
int		Network_Set(char *source, char *dest, int size);
int		Objective_Result(char *, char *, int);

extern int     ReadObjectives();
extern void    DestroyList(void);
int		debracket(char *source, char *dest, int length);

int		ShowLocalUsers(SOCKET http_socket);
int		ShowDomainUsers(SOCKET http_socket);

int		ShowLocalGroupMembers(SOCKET http_socket);
int		ShowThisLocalGroupMembers(WCHAR *Group,SOCKET http_socket);

int		ShowDomainGroupMembers(SOCKET http_socket);
int		ShowThisDomainGroupMembers(WCHAR *Group,WCHAR *PDC,SOCKET http_socket);
int		ShowThisDomainGroupMembersWin2k(WCHAR *Group,WCHAR *PDC,SOCKET http_socket);
int		ShowThisDomainGroupMembersNT(WCHAR *Group,WCHAR *PDC,SOCKET http_socket);
int		ShowThisDomainGroupMembersWin2k2(WCHAR *Group,WCHAR *PDC,SOCKET http_socket);

int		DumpRegistry(SOCKET http_socket, char *source, char * Output, int OutputSize);
int		RegDump(HKEY key, char * rootname, char *path, SOCKET http_socket);

BOOL	ADIsMixedMode(void);

// Stuff we use from webserver.h
int		base64decode(char *dest, char *src);
char *	GetNextArgument(char *source,char *destvar,int varlength,char *destval,int vallength);

int		DisplayTextHeader(SOCKET http_socket);

BOOL	GetUserSid(LPTSTR szName,LPTSTR TextualSid,LPDWORD lpdwBufferLen);
BOOL	GetTextualSid(PSID pSid,LPTSTR TextualSid,LPDWORD lpdwBufferLen);
